document.addEventListener("DOMContentLoaded", function() {
    var lazySections = document.querySelectorAll('.lazy-section');

    function lazyLoadVideo(video) {
        var src = video.dataset.src;
        if (src) {
            video.src = src;
        }
    }

    function convertSrcToDataSrc(section) {
        let iframes = section.querySelectorAll('iframe');
        iframes.forEach(iframe => {
            if (iframe.src) {
                iframe.dataset.src = iframe.src;
                iframe.src = '';
            }
        });
    }

    if ('IntersectionObserver' in window) {
        let observer = new IntersectionObserver((entries, observer) => {
            entries.forEach(entry => {
                if (entry.isIntersecting) {
                    let section = entry.target;
                    section.classList.add('loaded');
                    // Load dynamic content if any
                    if (section.dataset.lazyShortcode) {
                        section.innerHTML = section.dataset.lazyShortcode;
                    }
                    // Lazy load videos
                    let videos = section.querySelectorAll('iframe[data-src]');
                    videos.forEach(lazyLoadVideo);
                    observer.unobserve(section);
                }
            });
        });

        lazySections.forEach(section => {
            convertSrcToDataSrc(section);
            observer.observe(section);
        });
    } else {
        // Fallback for browsers that do not support IntersectionObserver
        lazySections.forEach(section => {
            section.classList.add('loaded');
            if (section.dataset.lazyShortcode) {
                section.innerHTML = section.dataset.lazyShortcode;
            }
            let videos = section.querySelectorAll('iframe[data-src]');
            videos.forEach(lazyLoadVideo);
        });
    }

    // Add event listener for user interaction with the video
    document.addEventListener('click', function(event) {
        if (event.target.tagName === 'IFRAME' && event.target.dataset.src) {
            lazyLoadVideo(event.target);
        }
    });
});
