<?php
/*
Plugin Name: Lazyload Elements
Description: The Lazyload Elements plugin enhances your website's performance by deferring the loading of specific sections or elements until they come into view. This method, known as lazy loading, improves page load times and provides a better user experience.
Version: 1.2
Author: Fred van der Meijde - WP Freelancer
Author URI: https://wpfreelancer.dev
*/

if (!defined('ABSPATH')) {
    exit; // Exit if accessed directly.
}

// Enqueue the lazy load script and style only on the frontend
function lazyload_elements_enqueue_script() {
    if (!is_admin() && !isset($_GET['et_fb']) && !isset($_GET['elementor-preview']) && !isset($_GET['vc_editable']) && !isset($_GET['fl_builder'])) {
        wp_enqueue_script(
            'lazyload-elements-script',
            plugin_dir_url(__FILE__) . 'js/lazyload-elements.js',
            array(),
            null,
            true
        );

        wp_enqueue_style(
            'lazyload-elements-style',
            plugin_dir_url(__FILE__) . 'css/lazyload-elements.css'
        );
    }
}
add_action('wp_enqueue_scripts', 'lazyload_elements_enqueue_script');

// Add a settings link to the plugin
function lazyload_elements_plugin_settings_link($links) {
    $settings_link = '<a href="https://wpfreelancer.dev/lazyload-elements/" target="_blank">How to Use</a>';
    array_unshift($links, $settings_link);
    return $links;
}
add_filter('plugin_action_links_' . plugin_basename(__FILE__), 'lazyload_elements_plugin_settings_link');
?>
